#
# spec file for package python3-numpy-doc
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-numpy-doc
Version:        1.9.3
Release:        3.6
Url:            http://www.numpy.org/
Summary:        Documentation for python3-numpy
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         https://pypi.python.org/packages/source/n/numpy/numpy-%{version}.tar.gz
# PATCH-FIX-OPENSUSE numpy-buildfix.patch -- openSUSE-specific build fixes
Patch0:         numpy-buildfix.patch
# PATCH-FIX-OPENSUSE numpy-1.9.0-remove-__declspec.patch -- fix for spurious compiler warnings that cause build failure
Patch1:         numpy-1.9.0-remove-__declspec.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-doc
BuildRequires:  python3-matplotlib
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-numpydoc
BuildRequires:  python3-pyparsing
BuildArch:      noarch
Recommends:     python3-numpy
Provides:       python3-numpy-doc-html = 1.7.1
Obsoletes:      python3-numpy-doc-html < 1.7.1
Provides:       python3-numpy-doc-pdf = 1.7.1
Obsoletes:      python3-numpy-doc-pdf < 1.7.1

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

This package provides the documentation for NumPy

%prep
%setup -q -n numpy-%{version}
%patch0 -p1
%patch1 -p1
# Patch in intersphinx file from pytho3-doc:
sed -i "s|'http://docs.python.org/dev': None|'http://docs.python.org/dev': '/usr/share/doc/packages/python3/html/objects.inv'|" doc/source/conf.py
# Avoid autosummary extensions, summaries are incomplete and it would fail:
sed -i "s|, 'sphinx.ext.autosummary'||" doc/source/conf.py

%build
cd doc
2to3 -wvn .
make html PYVER=%{py3_ver}

%install

%files
%defattr(-,root,root)
%doc doc/build/html

%changelog
* Wed Sep 23 2015 arun@gmx.de
- update to version 1.9.3:
  * #5866: fix error finding Python headers when build_ext --include-dirs is set;
  * #6016: fix np.loadtxt error on Python 3.5 when reading from gzip files;
  * #5555: Replace deprecated options for ifort;
  * #6096: remove /GL for VS2015 in check_long_double_representation;
  * #6141: enable Visual Studio 2015 C99 features;
  * #6171: revert C99 complex for MSVC14.
* Mon Mar  2 2015 toddrme2178@gmail.com
- Update to 1.9.2: Bugfix release
  * #5316: fix too large dtype alignment of strings and complex types
  * #5424: fix ma.median when used on ndarrays
  * #5481: Fix astype for structured array fields of different byte order
  * #5354: fix segfault when clipping complex arrays
  * #5524: allow np.argpartition on non ndarrays
  * #5612: Fixes ndarray.fill to accept full range of uint64
  * #5155: Fix loadtxt with comments=None and a string None data
  * #4476: Masked array view fails if structured dtype has datetime component
  * #5388: Make RandomState.set_state and RandomState.get_state threadsafe
  * #5390: make seed, randint and shuffle threadsafe
  * #5374: Fixed incorrect assert_array_almost_equal_nulp documentation
  * #5393: Add support for ATLAS > 3.9.33.
  * #5313: PyArray_AsCArray caused segfault for 3d arrays
  * #5492: handle out of memory in rfftf
  * #4181: fix a few bugs in the random.pareto docstring
  * #5359: minor changes to linspace docstring
  * #4723: fix a compile issues on AIX
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Thu Nov  6 2014 toddrme2178@gmail.com
- Update to 1.9.1: Bugfix release
  * gh-5184: restore linear edge behaviour of gradient to as it was in < 1.9.
    The second order behaviour is available via the `edge_order` keyword
  * gh-4007: workaround Accelerate sgemv crash on OSX 10.9
  * gh-5100: restore object dtype inference from iterable objects without
    `len()`
  * gh-5163: avoid gcc-4.1.2 (red hat 5) miscompilation causing a crash
  * gh-5138: fix nanmedian on arrays containing inf
  * gh-5203: copy inherited masks in MaskedArray.__array_finalize__
  * gh-2317: genfromtxt did not handle filling_values=0 correctly
  * gh-5067: restore api of npy_PyFile_DupClose in python2
  * gh-5063: cannot convert invalid sequence index to tuple
  * gh-5082: Segmentation fault with argmin() on unicode arrays
  * gh-5095: don't propagate subtypes from np.where
  * gh-5104: np.inner segfaults with SciPy's sparse matrices
  * gh-5136: Import dummy_threading if importing threading fails
  * gh-5148: Make numpy import when run with Python flag '-OO'
  * gh-5147: Einsum double contraction in particular order causes ValueError
  * gh-479: Make f2py work with intent(in out)
  * gh-5170: Make python2 .npy files readable in python3
  * gh-5027: Use 'll' as the default length specifier for long long
  * gh-4896: fix build error with MSVC 2013 caused by C99 complex support
  * gh-4465: Make PyArray_PutTo respect writeable flag
  * gh-5225: fix crash when using arange on datetime without dtype set
  * gh-5231: fix build in c99 mode
* Mon Sep  8 2014 toddrme2178@gmail.com
- Update to 1.9.0
  Highlights
  * Numerous performance improvements in various areas, most
    notably indexing and operations on small arrays are
    significantly faster. Indexing operations now also release the
    GIL.
  * Addition of nanmedian and nanpercentile rounds out the
    nanfunction set.
- Remove upstreamed numpy-double-double-le.patch
- Add numpy-1.9.0-remove-__declspec.patch
  Fixes spurious warnings during build.  These warnings are related
  to a windows-specific function that is not built, so the patch
  just removed the function.
  See:
  http://lists.opensuse.org/opensuse-packaging/2014-09/msg00004.html
- Added patch tag for numpy-buildfix.patch
* Mon Aug 11 2014 toddrme2178@gmail.com
- Update to 1.8.2: Bugfix release
  * gh-4836: partition produces wrong results for multiple selections in equal ranges
  * gh-4656: Make fftpack._raw_fft threadsafe
  * gh-4628: incorrect argument order to _copyto in in np.nanmax, np.nanmin
  * gh-4642: Hold GIL for converting dtypes types with fields
  * gh-4733: fix np.linalg.svd(b, compute_uv=False)
  * gh-4853: avoid unaligned simd load on reductions on i386
  * gh-4722: Fix seg fault converting empty string to object
  * gh-4613: Fix lack of NULL check in array_richcompare
  * gh-4774: avoid unaligned access for strided byteswap
  * gh-650: Prevent division by zero when creating arrays from some buffers
  * gh-4602: ifort has issues with optimization flag O2, use O1
- Switch to pypi download location
- Changed Url to current home page
- Minor spec file cleanups
* Mon Apr 14 2014 arun@gmx.de
- update to 1.8.1, bugfix release
* Mon Nov  4 2013 toddrme2178@gmail.com
- Fix building
- python3-2to3 is not needed for the main package but is still
  needed for the docs
* Thu Oct 31 2013 toddrme2178@gmail.com
- Update to 1.8.0
  Highlights:
  * New, no 2to3, Python 2 and Python 3 are supported by a common code base.
  * New, gufuncs for linear algebra, enabling operations on stacked arrays.
  * New, inplace fancy indexing for ufuncs with the ``.at`` method.
  * New, ``partition`` function, partial sorting via selection for fast median.
  * New, ``nanmean``, ``nanvar``, and ``nanstd`` functions skipping NaNs.
  * New, ``full`` and ``full_like`` functions to create value initialized arrays.
  * New, ``PyUFunc_RegisterLoopForDescr``, better ufunc support for user dtypes.
  * Numerous performance improvements in many areas.
- Add a new flag to easily enable/disable atlas support for if it
  ever gets fixed in the future
- Rebase numpy-buildfix.patch
- Remove upstreamed numpy-doc-postprocess-encoding.patch
* Thu Aug 15 2013 speilicke@suse.com
- Buildrequire python3-2to3 on 12.2
* Mon Aug 12 2013 speilicke@suse.com
- Drop python3-numpydoc, it's available on PyPI as a seperate package
- Add numpy-doc-postprocess-encoding.patch: Fix encoding issues in doc/postprocess.py
- Only build HTML documentation, PDF just isn't worth it
- Fix requirements, don't depend on python(abi), it's docs!
* Wed Jun 19 2013 speilicke@suse.com
- Initial version
